@@ -3,5 +3,5 @@
 #undef HAVE_GETTEXT
 #undef ENABLE_NLS
 #undef GETTEXT_PACKAGE
-#undef BONOBO_EXPLICIT_TRANSLATION_DOMAIN
+#undef GNOME_DB_EXPLICIT_TRANSLATION_DOMAIN
 #undef BUILD_CAPPLET
