@@ -25,5 +25,8 @@
 #include <gtk/gtkwidget.h>
 
 GtkWidget *provider_config_new (void);
+void       provider_config_select_all (GtkWidget *provider);
+void       provider_config_unselect_all (GtkWidget *provider);
+gboolean   provider_config_has_selection (GtkWidget *provider);
 
 #endif
