@@ -1,5 +1,5 @@
 /* GNOME DB library
- * Copyright (C) 1999-2001 The Free Software Foundation
+ * Copyright (C) 1999-2002 The GNOME Foundation.
  *
  * AUTHORS:
  *      Rodrigo Moya <rodrigo@gnome-db.org>
@@ -21,6 +21,8 @@
  */
 
 #include <libgnomedb/gnome-db-browser.h>
+#include <libgnomedb/gnome-db-util.h>
+#include "gnome-db-browser-private.h"
 
 typedef struct {
 } GnomeDbBrowserTypesPrivate;
