@@ -96,11 +96,15 @@ guint 	      gnome_db_config_add_listener (const gchar *path,
 					    gpointer user_data);
 
 void          gnome_db_config_remove_listener (guint id);
+
 /*
  * Known configuration entries
  */
 
-#define GNOME_DB_CONFIG_KEY_BROWSER_PANED_POSITION "/apps/gnome-db/Browser/PanedPosition"
+#define GNOME_DB_CONFIG_KEY_BROWSER_PANED_POSITION   "/apps/gnome-db/Browser/PanedPosition"
+#define GNOME_DB_CONFIG_KEY_EDITOR_HIGHLIGHT         "/apps/gnome-db/Editor/Highlight"
+#define GNOME_DB_CONFIG_KEY_EDITOR_SHOW_LINE_NUMBERS "/apps/gnome-db/Editor/ShowLineNumbers"
+#define GNOME_DB_CONFIG_KEY_EDITOR_TAB_STOP          "/apps/gnome-db/Editor/TabStop"
 
 G_END_DECLS
 
