@@ -70,9 +70,8 @@ gnome_db_control_widget_finalize (GObject *object)
 	g_return_if_fail (GNOME_DB_IS_CONTROL_WIDGET (wid));
 
 	/* free memory */
-	if (wid->priv->bonobo_widget != NULL)
-		g_object_unref (wid->priv->bonobo_widget);
 	g_free (wid->priv->iid);
+	wid->priv->iid = NULL;
 
 	g_free (wid->priv);
 	wid->priv = NULL;
@@ -105,14 +104,20 @@ gnome_db_control_widget_get_type (void)
 
 /**
  * gnome_db_control_widget_construct
+ * @wid:
+ * @id:
+ * @uic:
+ *
+ *
+ * 
+ * Returns:
  */
 GtkWidget *
 gnome_db_control_widget_construct (GnomeDbControlWidget *wid,
 				   const gchar *id,
 				   Bonobo_UIContainer uic)
 {
-	g_return_val_if_fail (GNOME_DB_IS_CONTROL_WIDGET (wid),
-			      GTK_WIDGET (wid));
+	g_return_val_if_fail (GNOME_DB_IS_CONTROL_WIDGET (wid), GTK_WIDGET (wid));
 
 	wid->priv->iid = g_strdup(id);
 
@@ -148,7 +153,7 @@ gnome_db_control_widget_construct (GnomeDbControlWidget *wid,
 GtkWidget *
 gnome_db_control_widget_new (const gchar *id, Bonobo_UIContainer uic)
 {
-	GnomeDbControlWidget* wid;
+	GnomeDbControlWidget *wid;
 	
 	g_return_val_if_fail(id != NULL, NULL);
 	
@@ -156,6 +161,36 @@ gnome_db_control_widget_new (const gchar *id, Bonobo_UIContainer uic)
 	return gnome_db_control_widget_construct (wid, id, uic);
 }
 
+/**
+ * gnome_db_control_widget_new_from_corba
+ * @control:
+ * @uic:
+ *
+ *
+ *
+ * Returns:
+ */
+GtkWidget *
+gnome_db_control_widget_new_from_corba (Bonobo_Control control, Bonobo_UIContainer uic)
+{
+	GnomeDbControlWidget *wid;
+
+	g_return_val_if_fail (control != CORBA_OBJECT_NIL, NULL);
+
+	wid = g_object_new (GNOME_DB_TYPE_CONTROL_WIDGET, NULL);
+
+	wid->priv->bonobo_widget = bonobo_widget_new_control_from_objref (control, uic);
+	if (!BONOBO_IS_WIDGET (wid->priv->bonobo_widget)) {
+		g_object_unref (G_OBJECT (wid));
+		return NULL;
+	}
+
+	gtk_widget_show (wid->priv->bonobo_widget);
+	gtk_box_pack_start (GTK_BOX (wid), wid->priv->bonobo_widget, TRUE, TRUE, 0);
+
+	return GTK_WIDGET (wid);
+}
+
 /**
  * gnome_db_control_widget_is_alive
  * @wid: a #GnomeDbControlWidget widget
@@ -163,7 +198,7 @@ gnome_db_control_widget_new (const gchar *id, Bonobo_UIContainer uic)
  * Pings the given #GnomeDbControlWidget widget to see if the underlying
  * CORBA server is still alive.
  *
- * Returns: TRUE if alive, FALSE if dead
+ * Returns: TRUE if alive, FALSE if dead.
  */
 gboolean
 gnome_db_control_widget_is_alive (GnomeDbControlWidget *wid)
@@ -233,6 +268,8 @@ gnome_db_control_widget_deactivate (GnomeDbControlWidget *wid)
  * @wid: a #GnomeDbControlWidget widget.
  *
  * Returns the ID of the underlying control.
+ *
+ * Returns: the ID of the underlying control.
  */
 const gchar *
 gnome_db_control_widget_get_id (GnomeDbControlWidget *wid)
@@ -243,6 +280,11 @@ gnome_db_control_widget_get_id (GnomeDbControlWidget *wid)
 
 /**
  * gnome_db_control_widget_get_objref
+ * @wid:
+ *
+ *
+ * 
+ * Returns:
  */
 Bonobo_Unknown
 gnome_db_control_widget_get_objref (GnomeDbControlWidget *wid)
@@ -252,3 +294,20 @@ gnome_db_control_widget_get_objref (GnomeDbControlWidget *wid)
 
 	return bonobo_widget_get_objref (BONOBO_WIDGET (wid->priv->bonobo_widget));
 }
+
+/**
+ * gnome_db_control_widget_get_ui_container
+ * @wid:
+ *
+ *
+ *
+ * Returns:
+ */
+Bonobo_UIContainer
+gnome_db_control_widget_get_ui_container (GnomeDbControlWidget *wid)
+{
+	g_return_val_if_fail (GNOME_DB_IS_CONTROL_WIDGET (wid), CORBA_OBJECT_NIL);
+	g_return_val_if_fail (BONOBO_IS_WIDGET (wid->priv->bonobo_widget), CORBA_OBJECT_NIL);
+
+	return bonobo_widget_get_ui_container (BONOBO_WIDGET (wid->priv->bonobo_widget));
+}
