@@ -20,9 +20,10 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <libgnomedb/gnome-db-control.h>
 #include <bonobo/bonobo-property-bag.h>
+#include <libgda/gda-marshal.h>
 #include <bonobo/bonobo-ui-util.h>
+#include <libgnomedb/gnome-db-control.h>
 
 #define PARENT_TYPE BONOBO_TYPE_CONTROL
 
@@ -42,6 +43,8 @@ static void gnome_db_control_finalize   (GObject *object);
 
 enum {
 	ACTIVATED,
+	GET_PROPERTY,
+	SET_PROPERTY,
 	LAST_SIGNAL
 };
 
@@ -71,6 +74,7 @@ get_prop_cb (BonoboPropertyBag *bag, BonoboArg *arg, guint arg_id, gpointer user
         GnomeDbControl *control = (GnomeDbControl *) user_data;
 
         g_return_if_fail (GNOME_DB_IS_CONTROL (control));
+	g_signal_emit (G_OBJECT (control), control_signals[GET_PROPERTY], 0, arg, arg_id);
 }
 
 static void
@@ -79,6 +83,7 @@ set_prop_cb (BonoboPropertyBag *bag, const BonoboArg *arg, guint arg_id, gpointe
         GnomeDbControl *control = (GnomeDbControl *) user_data;
 
         g_return_if_fail (GNOME_DB_IS_CONTROL (control));
+	g_signal_emit (G_OBJECT (control), control_signals[SET_PROPERTY], 0, arg, arg_id);
 }
 
 /*
@@ -103,6 +108,22 @@ gnome_db_control_class_init (GnomeDbControlClass *klass)
 		              NULL, NULL,
 			      g_cclosure_marshal_VOID__VOID,
 			      G_TYPE_NONE, 0);
+	control_signals[GET_PROPERTY] =
+		g_signal_new ("get_property",
+			      G_TYPE_FROM_CLASS (object_class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (GnomeDbControlClass, get_property),
+			      NULL, NULL,
+			      gda_marshal_VOID__POINTER_UINT,
+			      G_TYPE_NONE, 2, G_TYPE_POINTER, G_TYPE_UINT);
+	control_signals[SET_PROPERTY] =
+		g_signal_new ("set_property",
+			      G_TYPE_FROM_CLASS (object_class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (GnomeDbControlClass, set_property),
+			      NULL, NULL,
+			      gda_marshal_VOID__POINTER_UINT,
+			      G_TYPE_NONE, 2, G_TYPE_POINTER, G_TYPE_UINT);
 }
 
 static void
@@ -159,6 +180,12 @@ gnome_db_control_get_type (void)
 
 /**
  * gnome_db_control_construct
+ * @control:
+ * @widget:
+ *
+ *
+ *
+ * Returns:
  */
 GnomeDbControl *
 gnome_db_control_construct (GnomeDbControl *control, GtkWidget *widget)
