@@ -111,7 +111,7 @@ gnome_db_list_class_init (GnomeDbListClass *klass)
 		g_signal_new ("selection_cleared",
 			      G_TYPE_FROM_CLASS (object_class),
 			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (GnomeDbGridClass, row_selected),
+			      G_STRUCT_OFFSET (GnomeDbGridClass, selection_cleared),
 			      NULL, NULL,
 			      g_cclosure_marshal_VOID__VOID,
 			      G_TYPE_NONE, 0);
@@ -241,6 +241,12 @@ gnome_db_list_new (void)
 
 /**
  * gnome_db_list_new_with_model
+ * @model:
+ * @col:
+ *
+ *
+ *
+ * Returns:
  */
 GtkWidget *
 gnome_db_list_new_with_model (GdaDataModel *model, gint col)
@@ -255,6 +261,11 @@ gnome_db_list_new_with_model (GdaDataModel *model, gint col)
 
 /**
  * gnome_db_list_get_model
+ * @list:
+ *
+ *
+ *
+ * Returns:
  */
 GdaDataModel *
 gnome_db_list_get_model (GnomeDbList *list)
