@@ -229,14 +229,27 @@ model_row_updated_cb (GdaDataModel *model, gint row, gpointer user_data)
 static void
 model_row_removed_cb (GdaDataModel *model, gint row, gpointer user_data)
 {
-	GtkTreePath *path;
+	DataModelInfo *info = NULL;
+	gint i, row_count;
+	GtkTreeIter iter;
 	GtkTreeView *tree_view = user_data;
+	
+	gtk_tree_model_iter_nth_child (gtk_tree_view_get_model (tree_view), &iter, NULL, row);
+	gtk_tree_store_remove (gtk_tree_view_get_model (tree_view), &iter);
+	row_count = gda_data_model_get_n_rows (model);
 
-	path = gtk_tree_path_new ();
-	gtk_tree_path_append_index (path, row);
-	gtk_tree_model_row_deleted (gtk_tree_view_get_model (tree_view), path);
+	/* renumber following rows */
+	for (i = 0; i < row_count; i++) {
+		gtk_tree_model_iter_nth_child (gtk_tree_view_get_model (tree_view), &iter, NULL, i);
+		gtk_tree_model_get (gtk_tree_view_get_model (tree_view), &iter, 0, &info, -1);
 
-	gtk_tree_path_free (path);
+		if (info->row > row) {
+			info->row--;
+			gtk_tree_store_set (gtk_tree_view_get_model (tree_view), &iter,
+					    0, info,
+					    -1);
+		}
+	}
 }
 
 static gboolean
